/*
	UltrasoundSensor.h - Library for controling
	an Ultrasound Range sensor.
	Created by Jrgen Vendorf, August 12, 2012.
	Released into the public domain.

	To use this library, do the following:
	1. In your sketchbook folder, create a folder called "libraries".
	2. In "libraries" create a folder called "UltrasoundSensor".
	3. Copy the UltrasoundSensor file ".cpp" and ".h" into the "UltrasoundSensor" folder.

	The constructor takes 2 parameters:
		First the pin for the echo signal. This can be pin 2 or 3, as it has to be able to use interrupt.
		Second is the trigger pin.
	
	Functions:
		Ping()     - Activates the trigger pin.
		PingCM()   - Returns the distance meassured in Cm.
		PingINCH() - Returns the distance meassured in Inches.
	
	Eks.:

	#include "UltrasoundSensor.h"

	// 3 is the Trigger pin, 4 is the Echo pin
	UltrasoundSensor RangeSensor = UltrasoundSensor(3,4);

	void setup() {
	}

	void loop() {
		float Distance;

		RangeSensor.Ping();
		delayMicroseconds(60); // Adviced delay for the HC-SR04 ultrasound range sensor.
		Distance = RangeSensor.PingCM();
	}
*/
#include "Arduino.h"
#include "UltrasoundSensor.h"

int UltrasoundSensor::PingPinTrigger;
int UltrasoundSensor::PingPinEcho;
long UltrasoundSensor::PingStartTime;
long UltrasoundSensor::PingReturnTime;

void UltrasoundSensor::PingEcho() {
  long timing;
  timing = micros();
  if (digitalRead(PingPinEcho) == HIGH) PingStartTime = timing;
  if (digitalRead(PingPinEcho) == LOW) PingReturnTime = timing-PingStartTime;
}
 
UltrasoundSensor::UltrasoundSensor(int inEcho, int inTrigger) {
  PingPinTrigger = inTrigger;
  PingPinEcho = inEcho;
  pinMode(PingPinTrigger, OUTPUT);
  digitalWrite(PingPinTrigger,LOW);
  pinMode(PingPinEcho, INPUT);
  if (PingPinEcho == 2) attachInterrupt(0, PingEcho, CHANGE);
  if (PingPinEcho == 3) attachInterrupt(1, PingEcho, CHANGE);
}

void UltrasoundSensor::Ping() {
  digitalWrite(PingPinTrigger,HIGH);
  delayMicroseconds(10);
  digitalWrite(PingPinTrigger,LOW);
}

float UltrasoundSensor::PingCM() {
  return ((float)PingReturnTime/58);
}
float UltrasoundSensor::PingINCH() {
  return ((float)PingReturnTime/148);
}

