/*
	UltrasoundSensor.h - Library for controling
	an Ultrasound Range sensor.
	Created by Jrgen Vendorf, August 12, 2012.
	Released into the public domain.

	To use this library, do the following:
	1. In your sketchbook folder, create a folder called "libraries".
	2. In "libraries" create a folder called "UltrasoundSensor".
	3. Copy the UltrasoundSensor file ".cpp" and ".h" into the "UltrasoundSensor" folder.

	The constructor takes 2 parameters:
		First the pin for the echo signal. This can be pin 2 or 3, as it has to be able to use interrupt.
		Second is the trigger pin.
	
	Functions:
		Ping()     - Activates the trigger pin.
		PingCM()   - Returns the distance meassured in Cm.
		PingINCH() - Returns the distance meassured in Inches.
	
	Eks.:

	#include "UltrasoundSensor.h"

	// 3 is the Trigger pin, 4 is the Echo pin
	UltrasoundSensor RangeSensor = UltrasoundSensor(3,4);

	void setup() {
	}

	void loop() {
		float Distance;

		RangeSensor.Ping();
		delayMicroseconds(60); // Adviced delay for the HC-SR04 ultrasound range sensor.
		Distance = RangeSensor.PingCM();
	}
*/
 
#ifndef UltrasoundSensor_h
#define UltrasoundSensor_h

#include "Arduino.h"
 
class UltrasoundSensor {
	private:
		static int PingPinTrigger;
		static int PingPinEcho;
		static long PingStartTime;
		static long PingReturnTime;

		static void PingEcho();

	public:
		UltrasoundSensor(int inEcho, int inTrigger);
		void Ping();
		float PingCM();
		float PingINCH();
};

#endif